@@ -12,12 +12,26 @@ def get_sp500():
 	df = pd.read_html(str(table))
 	return df[0]
 
-def get_nasdaq(): # Right now this returns nasdaq-100, should I make it just regular nasdaq (3,300 stocks)
-	request = get('https://en.wikipedia.org/wiki/Nasdaq-100')
-	soup = BeautifulSoup(request.text, 'lxml')
-	table = soup.find('table', {'id': 'constituents'})
-	df = pd.read_html(str(table))
-	return df[0]
+def get_nasdaq(as_list=True): # Nasdaq + NYSE + AMEX
+    dfs = []
+    for letter in 'abcdefghijklmnopqrstuvwxyz':
+        request = get(f'https://www.advfn.com/nasdaq/nasdaq.asp?companies={letter.upper()}')
+        soup = BeautifulSoup(request.text, 'lxml')
+        table = soup.find('table', {'class': 'market tab1'})
+        df = pd.read_html(str(table))[0]
+        df.columns = df.iloc[1].tolist()
+        df = df.iloc[2:]
+        df = df.reset_index()
+        df = df['Symbol']
+        dfs.append(df)
+  
+	# Will this work since they are series?
+    df = pd.concat(dfs)
+    df = df.reset_index()
+    df = df['Symbol']
+    if as_list:
+        return df.tolist()
+    return df
 
 def get_nyse(): # Test to see if duplicate tickers on backend or Django webapp
 	dfs = []
